The srpareto_optimize() function generates an optimized proposal for a targeted Pareto Distribution.
The proposal can be customized and adjusted based on various options provided by the user.
srpareto_optimize(
scale = NULL,
shape = NULL,
xl = NULL,
xr = NULL,
steps = 4091,
proposal_range = NULL,
theta = 0.1,
target_sample_size = 1000,
verbose = FALSE
)The user does not need to store the returned value, because the package internally cashes the proposal. However, we explain here the full returned proposal for advanced users.
A list containing the optimized proposal and related parameters for the specified built-in distribution: #'
dataDetailed information about the proposal steps, including x, s_upper, p_a, and s_upper_lower.
areasThe areas under the left tail, steps, and right tail of the proposal distribution.
steps_numberThe number of steps in the proposal.
f_paramsThe parameters (scale and shape) of the Beta distribution.
(optional) Numeric. scale parameter of the Pareto Distribution. Defaults to NULL, which implies a scalable proposal with scale = 1.
(optional) Numeric. shape parameter of the Pareto Distribution. Defaults to NULL, which implies a scalable proposal with shape = 1.
Numeric. Left truncation bound for the target distribution. Defaults to -Inf, representing no left truncation.
Numeric. Right truncation bound for the target distribution. Defaults to Inf, representing no right truncation.
(optional) Integer. Desired number of steps in the proposal. Defaults to NULL, which means the number of steps is determined automatically during optimization.
(optional) Numeric vector. Specifies the range for optimizing the steps part of the proposal. Defaults to NULL, indicating automatic range selection.
Numeric. A parameter for proposal optimization. Defaults to 0.1.
(optional) Integer. Target sample size for proposal optimization. Defaults to 1000.
Boolean. If TRUE, detailed optimization information, including areas and steps, will be displayed. Defaults to FALSE.
When srpareto_optimize() is explicitly called:
A proposal is created and cached. If no parameters are provided, a standard proposal is created with rate = 1.
Providing rate creates a custom proposal, which is cached for use with srpareto_custom().
The optimization process can be controlled via parameters such as steps, proposal_range, or
theta. If no parameters are provided, the proposal is optimized via brute force based on the.
target_sample_size.
srpareto_custom: Function to sample from a custom proposal tailored to user specifications.
# Generate scalable proposal that with rate = 1, that has 4096 steps
scalable_proposal <- srpareto_optimize(steps = 4096)
# Generate custom proposal that with scale = 4
scalable_proposal <- srpareto_optimize(scale = 4)
Run the code above in your browser using DataLab